/*
 * BWSBEXP.H
 *
 *   Balanced Expression support for Codewright by Starbase Corp.
 *
 *   Purpose: 
 *      BWSBEXP.DLL implements Balanced Expression support within Starbase
 *      Corporation's Codewright product.  Features supported within
 *      this library include balanced expression searching, selecting,
 *      matching and a configuration dialog screen.  Balanced expression
 *      entries are configured via a dialog box and entries are maintained
 *      on a per file type basis (i.e. different balanced expressions
 *      for different languages based on the current buffer's extension).
 *
 *   Owner/Developer:  Brad Stumpf
 *                     406 Cozby Ave.
 *                     Coppell, TX 75019
 *
 *                     bstumpf@iadfw.net
 *
 *   Copyright (c) 1995 Stumpf Software Company
 *
 */

#ifndef __BWSBEXP_INCLUDED__
#define __BWSBEXP_INCLUDED__

// User flags (Cfg_Flags)
#define BEXP_CFG_USE_WORD_DELIMITERS   0x00000001L  // Word Delimited?
#define BEXP_CFG_IGN_CASE              0x00000002L  // Ignore Case?
#define BEXP_CFG_LEAVE_SEL_OPEN        0x00000004L  // Leave selection open?
#define BEXP_CFG_END_AT_EOL            0x00000008L  // End exp. at EOL?
#define BEXP_CFG_FIND_AT_BOL_ONLY      0x00000010L  // Exp. at BOL only?
#define BEXP_CFG_FLAGS_MASK            0x0000001FL  // mask of config flags

// Locator flags (Loc_Flags)
#define BEXP_LOC_TYPE_COMMENT          0x00010000L  // W/R: Comment?
#define BEXP_LOC_TYPE_QUOTE            0x00020000L  // W/R: Quote?
#define BEXP_LOC_TYPE_COMMENT_ML       0x00040000L  // R  : Multi-line Comment?
#define BEXP_LOC_IGN_IN_COMMENT        0x00100000L  // W/R: Ignore in Comment?
#define BEXP_LOC_IGN_IN_QUOTE          0x00200000L  // W/R: Ignore in Quote?
#define BEXP_LOC_SEARCH_SELECTION      0x00400000L  // W/R: Search sel only?
#define BEXP_LOC_FIND_BEG              0x01000000L  // W/R: Find/loc Beg exp?
#define BEXP_LOC_FIND_END              0x02000000L  // W/R: Find/loc End exp?
#define BEXP_LOC_FIND_MID              0x04000000L  // W/R: Find/loc Mid exp?
#define BEXP_LOC_FIND_MID_ALT          0x08000000L  // W/R: Find/loc Mid alternate?
#define BEXP_LOC_SELECT                0x10000000L  // W/R: Select bexp?
#define BEXP_LOC_KISS_PARTNER          0x20000000L  // W/R: Display pause?

#define BEXP_LOC_GROUP_MASK            0x0000FFFFL  // Mask:
#define BEXP_LOC_TYPE_MASK_USER        0x00030000L  // Mask:
#define BEXP_LOC_TYPE_MASK             0x00070000L  // Mask:
#define BEXP_LOC_IGN_IN_MASK           0x00300000L  // Mask:
#define BEXP_LOC_FIND_MASK             0x07000000L  // Mask:
#define BEXP_LOC_QREQ_MASK_USER        0x0003FFFFL  // Mask:
#define BEXP_LOC_QREQ_MASK             0x0007FFFFL  // Mask:
#define BEXP_LOC_FLAGS_MASK            0xFFFF0000L  // Mask:
#define BEXP_LOC_FLAGS_MASK_USER       0x3F73FFFFL  // Mask:
#define BEXP_LOC_FIND_MASK_USER        0x0F73FFFFL  // Mask:

// Find: Direction flags
#define BEXP_DIR_BACKWARD          -1
#define BEXP_DIR_MATCH_CURRENT      0
#define BEXP_DIR_FORWARD            1

// external functions
LPSTR DLL BWS_BExpVersion( void );
BOOL  DLL BWS_DlgBExpSetup( HWND hWndParent );
DWORD DLL BWS_BExpSetLocFlags( DWORD Loc_Flags );
DWORD DLL BWS_BExpQLocFlags( void );
DWORD DLL BWS_BExpSetExtLocFlags( LPSTR buf_ext, DWORD Loc_Flags );
DWORD DLL BWS_BExpQExtLocFlags( LPSTR buf_ext );
BOOL  DLL BWS_BExpSelect( int dir, DWORD Loc_Flags, DWORD extLoc_Flags_Mask );
BOOL  DLL BWS_BExpFind( int dir, DWORD Loc_Flags, DWORD extLoc_Flags_Mask );
BOOL  DLL BWS_BExpMatchAll( LPSTR beg_str, DWORD Loc_Flags, DWORD extLoc_Flags_Mask );
BOOL  DLL BWS_BExpAddEntry( LPSTR buf_ext, LPSTR beg_str, LPSTR end_str,
                            DWORD Cfg_Flags, DWORD Loc_Flags, int selType, LPSTR mid_str );
BOOL  DLL BWS_BExpRemoveExt( LPSTR buf_ext );
BOOL  DLL BWS_BExpAliasExt( LPSTR pm_OrigExt, LPSTR pm_DestExt );
BOOL  DLL BWS_BExpGetEntry( LPSTR buf_ext, LPSTR beg_str, LPSTR *end_str,
                            LPDWORD Cfg_Flags, LPDWORD Loc_Flags, LPINT selType,
                            LPSTR *mid_str );
BOOL  DLL BWS_BExpDeleteEntry( LPSTR buf_ext, LPSTR beg_str );
BOOL  DLL BWS_BExpSetExtConfig( LPSTR buf_ext, LPSTR pm_chLineCont, LPSTR pm_chEscape ); //bws;950108

#endif
